==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGraphToGlyphs.java <==
// java wrapper for vtkGraphToGlyphs object
//

package vtk;
import vtk.*;

public class vtkGraphToGlyphs extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGlyphType_2(int id0);
  public void SetGlyphType(int id0)
    { SetGlyphType_2(id0); }

  private native int GetGlyphType_3();
  public int GetGlyphType()
    { return GetGlyphType_3(); }

  private native void SetFilled_4(boolean id0);
  public void SetFilled(boolean id0)
    { SetFilled_4(id0); }

  private native boolean GetFilled_5();
  public boolean GetFilled()
    { return GetFilled_5(); }

  private native void FilledOn_6();
  public void FilledOn()
    { FilledOn_6(); }

  private native void FilledOff_7();
  public void FilledOff()
    { FilledOff_7(); }

  private native void SetScreenSize_8(double id0);
  public void SetScreenSize(double id0)
    { SetScreenSize_8(id0); }

  private native double GetScreenSize_9();
  public double GetScreenSize()
    { return GetScreenSize_9(); }

  private native void SetRenderer_10(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_10(id0); }

  private native long GetRenderer_11();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_11();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScaling_12(boolean id0);
  public void SetScaling(boolean id0)
    { SetScaling_12(id0); }

  private native boolean GetScaling_13();
  public boolean GetScaling()
    { return GetScaling_13(); }

  private native int GetMTime_14();
  public int GetMTime()
    { return GetMTime_14(); }

  public vtkGraphToGlyphs() { super(); }

  public vtkGraphToGlyphs(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-21-armv7h.pkg.tar.xz: vtk/vtkGraphToGlyphs.java <==
// java wrapper for vtkGraphToGlyphs object
//

package vtk;
import vtk.*;

public class vtkGraphToGlyphs extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGlyphType_2(int id0);
  public void SetGlyphType(int id0)
    { SetGlyphType_2(id0); }

  private native int GetGlyphType_3();
  public int GetGlyphType()
    { return GetGlyphType_3(); }

  private native void SetFilled_4(boolean id0);
  public void SetFilled(boolean id0)
    { SetFilled_4(id0); }

  private native boolean GetFilled_5();
  public boolean GetFilled()
    { return GetFilled_5(); }

  private native void FilledOn_6();
  public void FilledOn()
    { FilledOn_6(); }

  private native void FilledOff_7();
  public void FilledOff()
    { FilledOff_7(); }

  private native void SetScreenSize_8(double id0);
  public void SetScreenSize(double id0)
    { SetScreenSize_8(id0); }

  private native double GetScreenSize_9();
  public double GetScreenSize()
    { return GetScreenSize_9(); }

  private native void SetRenderer_10(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_10(id0); }

  private native long GetRenderer_11();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_11();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScaling_12(boolean id0);
  public void SetScaling(boolean id0)
    { SetScaling_12(id0); }

  private native boolean GetScaling_13();
  public boolean GetScaling()
    { return GetScaling_13(); }

  private native int GetMTime_14();
  public int GetMTime()
    { return GetMTime_14(); }

  public vtkGraphToGlyphs() { super(); }

  public vtkGraphToGlyphs(long id) { super(id); }
  public native long   VTKInit();

}
